@@ -8,23 +8,11 @@ from starlette.middleware import Middleware
 from fastapi_filter.middleware import CustomFilterMiddleware
 import uvicorn
 
-class FilterRouter(APIRoute):
-    def get_route_handler(self) -> Callable:
-        original_route_handler = super().get_route_handler()
 
-        async def custom_route_handler(request: Request) -> Response:
-            print("HEY MAN. DUCKY WAS HERE")
-            #raise HTTPException(status_code=401, detail="You encountered the wrong filter bud!")
-            
-        return custom_route_handler
-
-def newCallable(request: Request) -> Request:
-    print("HEY MAN. DUCKY WAS HERE")
+def MethodFilter(request: Request) -> Request:
     raise HTTPException(status_code=205)
-    
-    return request
 
-router = FilterAPIRouter(prefix= "/cars").includeFilterOnMethod(method= "DoNothing", filter=newCallable)
+router = FilterAPIRouter(prefix= "/cars").includeFilterOnMethod(method= "DoNothing", filter=MethodFilter)
 
 middleware = [
 Middleware(
